0 matches

11 px

10

95%

Systems & Variables

N2
Symbols

Scalar

Vector

Collapsed Variables

Linear Solvers

N2 Information

Left clicking on a node in the model hierarchy will navigate to that node.
Right clicking on a node in the model hierarchy will collapse/expand it.
Hovering over any cell in the matrix will display its connections as arrows. Clicking that cell will cause those arrows to persist.

# Toolbar Help

{d3_lib} {awesomplete_lib} {vk_beautify_lib} {pako_inflate_lib} {json5_lib} {{model_data}} {utils_lib} {symboltype_lib} {n2treenode_lib} {modeldata_lib} {n2style_lib} {n2window_lib} {n2layout_lib} {n2matrixcell_lib} {n2legend_lib} {n2matrix_lib} {n2arrow_lib} {n2search_lib} {n2toolbar_lib} {n2diagram_lib} {nodeinfo_lib} {n2userinterface_lib} {defaults_lib} {ptn2_lib}